@@ -68,7 +68,10 @@ module Test
                   "Incorrect expected message type in assert_nothing_failed")
           end
         else
-          if return_value_expected
+          case return_value_expected
+          when :dont_care
+            # do nothing
+          when true
             check(!return_value.nil?, "Should return a value")
           else
             check(return_value.nil?,
@@ -124,22 +127,30 @@ module Test
     class TestAssertions < TestCase
       include AssertionCheckable
 
-      def test_assert_block
-        check_nothing_fails {
-          assert_block {true}
-        }
-        check_nothing_fails {
-          assert_block("successful assert_block") {true}
-        }
-        check_nothing_fails {
-          assert_block("successful assert_block") {true}
-        }
-        check_fail("assert_block failed.") {
-          assert_block {false}
-        }
-        check_fail("failed assert_block") {
-          assert_block("failed assert_block") {false}
-        }
+      class TestAssertBlock < self
+        def test_pass_without_message
+          check_nothing_fails {
+            assert_block {true}
+          }
+        end
+
+        def test_pass_with_message
+          check_nothing_fails {
+            assert_block("successful assert_block") {true}
+          }
+        end
+
+        def test_failure_without_message
+          check_fail("assert_block failed.") {
+            assert_block {false}
+          }
+        end
+
+        def test_failure_with_message
+          check_fail("failed assert_block") {
+            assert_block("failed assert_block") {false}
+          }
+        end
       end
 
       class TestAssertEqual < self
@@ -502,8 +513,7 @@ EOM
         end
 
         message = <<-EOM
-Should expect a class of exception, Object.
-<false> is not true.
+<Object> must be a subclass of Exception, an object of Exception subclasses or a Module.
 EOM
         check_fail(message.chomp) do
           assert_nothing_raised(Object) do
@@ -628,6 +638,21 @@ EOM
         end
       end
 
+      def test_assert_raise_jruby
+        omit("For JRuby") unless Object.const_defined?(:Java)
+
+        exception = Java::JavaLang::StringIndexOutOfBoundsException
+
+        return_value = nil
+        check_nothing_fails(true) do
+          return_value = assert_raise(exception) do
+            Java::JavaLang::String.new("abc").char_at(4)
+          end
+        end
+        check(return_value.instance_of?(exception),
+              "Should have returned #{exception} but was #{return_value.class}")
+      end
+
       def test_assert_instance_of
         check_nothing_fails {
           assert_instance_of(String, "string")
@@ -804,22 +829,22 @@ EOM
       end
 
       def test_assert_nothing_raised
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           assert_nothing_raised {
             1 + 1
           }
         }
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           assert_nothing_raised("successful assert_nothing_raised") {
             1 + 1
           }
         }
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           assert_nothing_raised("successful assert_nothing_raised") {
             1 + 1
           }
         }
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           begin
             assert_nothing_raised(RuntimeError, StandardError, Comparable, "successful assert_nothing_raised") {
               raise ZeroDivisionError.new("ArgumentError")
@@ -827,7 +852,10 @@ EOM
           rescue ZeroDivisionError
           end
         }
-        check_fail("Should expect a class of exception, Object.\n<false> is not true.") {
+        expected_message =
+          "<Object> must be a subclass of Exception, " +
+          "an object of Exception subclasses or a Module."
+        check_fail(expected_message) {
           assert_nothing_raised(Object) {
             1 + 1
           }
